==> gitbook-plugin-sfe-new-search-1.0.16.tgz: package/assets/sfe-search.js <==
require([
    'gitbook',
    'jquery'
], function(gitbook, $) {
    var timer = null;
    var input;
    var inputVal = '';
    var kw = '';
    var lastKw = '';
    var searchRes = null;
    var searchData = '';
    var resHtml = '';
    var resTitle = '',
        resContent = '';
        var url;
    function htmlEncode(value){  
      return $('<div/>').text(value).html();  
    }  
    //Html解码获取Html实体  
    function htmlDecode(value){  
      return $('<div/>').html(value).text();  
    }  
    function checkInput () {
        lastKw = kw;
        kw = input.val();
        clearTimeout(timer);
        timer = setTimeout(function() {
            checkInput();
        }, 300);
        if (kw === '') {
            $('.normal').show();
            $('.result').remove();
            return;
        }
        if (kw === lastKw) {
            if (kw === '') {
                $('.normal').show();
                $('.result').remove();
                return;
            }
            //return;
        } else {
            url = "http://apmjs.baidu.com:8000/cgi-bin/psdoc-req.sh";
            $.ajax({
                url: "http://apmjs.baidu.com:8000/cgi-bin/psdoc-req.sh?query=" + kw,
                type: "GET",
                success: function (data) {
                    if (data && data.itemList && data.itemList.length > 0) {
                        $('.normal').hide();
                        $('.result').remove();
                        searchData = data.itemList;
                        searchData.forEach(function (item, index) {
                            resHtml = '<div class="result"><a class="res-link"  href="' + item.highLight_url + '"><div class="res-title">'+ item.title + '</div><div class="res-content">' + htmlEncode(item.highLight_content[0]) + '</div></a></div>';
                            searchRes.append(resHtml);
                        });
                    } else {
                        $('.normal').show();
                        $('.result').remove();
                    }
                },
                error: function () {
                    $('.normal').show();
                }
            });
        }
    }
    gitbook.events.bind("start", function(e) {
        var searchObj = $('<div id="book-search-input"></div>');
        input = $('<input type="text" placeholder="输入并搜索" />');
        searchRes = $('<div class="book-search-result"></div>');
        input.on('focus', function () {
            lastKw = input.val();
            inputVal = input.val();
            checkInput();
        });
        input.on('blur', function () {
            clearTimeout(timer);
            if (input.val() == '') {
                $('.normal').hide();
                $('.result').remove();
            }
        })
        searchObj.append(input);
        $('.book-summary').prepend(searchObj);
        $('.page-inner').prepend(searchRes);
    });
});

==> gitbook-plugin-sfe-new-search-1.0.18.tgz: package/assets/sfe-search.js <==
require([
    'gitbook',
    'jquery'
], function(gitbook, $) {
    var timer = null;
    var input;
    var inputVal = '';
    var kw = '';
    var lastKw = '';
    var searchRes = null;
    var searchData = '';
    var resHtml = '';
    var resTitle = '',
        resContent = '';
        var url;
    function htmlEncode(value){  
      return $('<div/>').text(value).html();  
    }  
    //Html解码获取Html实体  
    function htmlDecode(value){  
      return $('<div/>').html(value).text();  
    }  
    function checkInput () {
        lastKw = kw;
        kw = input.val();
        clearTimeout(timer);
        timer = setTimeout(function() {
            checkInput();
        }, 300);
        if (kw === '') {
            $('.normal').show();
            $('.result').remove();
            return;
        }
        if (kw === lastKw) {
            if (kw === '') {
                $('.normal').show();
                $('.result').remove();
                return;
            }
            //return;
        } else {
            url = "http://apmjs.baidu.com:8000/cgi-bin/psdoc-req.sh";
            $.ajax({
                url: "http://apmjs.baidu.com:8000/cgi-bin/psdoc-req.sh?query=" + kw,
                type: "GET",
                success: function (data) {
                    if (data && data.itemList && data.itemList.length > 0) {
                        $('.normal').hide();
                        $('.result').remove();
                        searchData = data.itemList;
                        searchData.forEach(function (item, index) {
                            resHtml = '<div class="result"><a class="res-link"  href="' + item.highLight_url + '"><div class="res-title">'+ item.title + '</div><div class="res-content">' + item.highLight_content[0].replace(/<[^>]+>/g, "") + '</div></a></div>';
                            searchRes.append(resHtml);
                        });
                    } else {
                        $('.normal').show();
                        $('.result').remove();
                    }
                },
                error: function () {
                    $('.normal').show();
                }
            });
        }
    }
    gitbook.events.bind("start", function(e) {
        var searchObj = $('<div id="book-search-input"></div>');
        input = $('<input type="text" placeholder="输入并搜索" />');
        searchRes = $('<div class="book-search-result"></div>');
        input.on('focus', function () {
            lastKw = input.val();
            inputVal = input.val();
            checkInput();
        });
        input.on('blur', function () {
            clearTimeout(timer);
            if (input.val() == '') {
                $('.normal').hide();
                $('.result').remove();
            }
        })
        searchObj.append(input);
        $('.book-summary').prepend(searchObj);
        $('.page-inner').prepend(searchRes);
    });
});
